==> bokain_models-0.2.76.tar.gz: lib/src/phrase.dart <==
class Phrase
{
  String get(List<String> phrase_keys, { Map<String, String> params : null, String separator : " ", bool capitalize_first : true})
  {
    List<String> phraseValues = new List();
    for (String key in phrase_keys)
    {
      if (key == null) return "";
      String value = key = key.toLowerCase();

      if (_phraseData.containsKey(key))
      {
        value = _phraseData[key];
        params?.forEach((paramName, paramVal)
        {
          value = value.replaceAll("%$paramName%", paramVal);
        });
      }
      phraseValues.add(value);
    }
    String phrase = phraseValues.join(separator);
    if (capitalize_first == true) phrase = phrase[0].toUpperCase() + phrase.substring(1, phrase.length);

    return phrase;
  }

  final Map<String, String> _phraseData =
  {
    "1_pronounced" : "1:a",
    "2_prounounced" : "2:a",
    "3_pronounced" : "3:e",
    "4_pronounced" : "4:e",
    "5_pronounced" : "5:e",
    "6_pronounced" : "6:e",
    "7_pronounced" : "7:e",
    "8_pronounced" : "8:e",
    "9_pronounced" : "9:e",
    "10_pronounced" : "10:e",
    "11_pronounced" : "11:e",
    "12_pronounced" : "12:e",
    "13_pronounced" : "13:e",
    "14_pronounced" : "14:e",
    "15_pronounced" : "15:e",
    "16_pronounced" : "16:e",
    "17_pronounced" : "17:e",
    "18_pronounced" : "18:e",
    "19_pronounced" : "19:e",
    "20_pronounced" : "20:e",
    "21_pronounced" : "21:a",
    "22_pronounced" : "22:a",
    "23_pronounced" : "23:e",
    "24_pronounced" : "24:e",
    "25_pronounced" : "25:e",
    "26_pronounced" : "26:e",
    "27_pronounced" : "27:e",
    "28_pronounced" : "28:e",
    "29_pronounced" : "29:e",
    "30_pronounced" : "30:e",
    "31_pronounced" : "31:a",
    "32_pronounced" : "32:a",
    "active" : "aktiv",
    "add" : "lägg till",
    "associate" : "anslut",
    "associated" : "ansluten",
    "associated_plural" : "anslutna",
    "at" : "på",
    "belongs_to" : "tillhör",
    "book" : "boka in",
    "bookable_plural" : "bokningsbara",
    "booking" : "bokning",
    "booking_cancel" : "avboka",
    "booking_confirm" : "bekräfta bokning",
    "booking_confirm_text" :  "kontrollera att uppgifterna ovan stämmer innan du slutför bokningen",
    "booking_confirmation" : "bokningsbekräftelse",
    "booking_confirmation_send" : "skicka bokningsbekräftelse till kunden",
    "booking_details" : "bokningsinformation",
    "booking_history" : "bokningshistorik",
    "booking_mode" : "bokningsläge",
    "booking_plural" : "bokningar",
    "booking_rank" : "bokningsranking",
    "break" : "rast",
    "calendar" : "kalender",
    "cancel" : "avbryt",
    "category" : "kategori",
    "city" : "stad",
    "close" : "stäng",
    "confirm" : "bekräfta",
    "confirm_remove" : "bekräfta borttagning av objekt",
    "confirm_save" : "du har osparade ändringar, tryck OK för att spara eller AVBRYT för att ignorera ändringarna",
    "comments_external" : "kommentarer (externa)",
    "comments_internal" : "kommentarer (interna)",
    "country" : "land",
    "country_gb" : "storbritannien",
    "country_se" : "sverige",
    "currency" : "kr",
    "customer" : "kund",
    "customer_plural" : "kunder",
    "customer_details" : "kunduppgifter",
    "dashboard" : "dashboard",
    "delete" : "ta bort",
    "description" : "beskrivning",
    "details" : "uppgifter",
    "disabled" : "inaktiverad",
    "duration" : "varaktighet",
    "duration_minutes" : "varaktighet (minuter)",
    "dynamic_time" : "dynamisk tid",
    "edit" : "redigera",
    "email" : "e-post",
    "email_pronounced" : "denna e-post",
    "error_occured" : "ett fel inträffade",
    "finish" : "slutför",
    "friday" : "fredag",
    "in_minutes" : "(minuter)",
    "information" : "information",
    "firstname" : "förnamn",
    "frozen" : "fryst",
    "function" : "funktion",
    "language" : "språk",
    "language_en" : "engelska",
    "language_sv" : "svenska",
    "lastname" : "efternamn",
    "login" : "logga in",
    "monday" : "måndag",
    "month" : "månad",
    "month_1" : "januari",
    "month_2" : "februari",
    "month_3" : "mars",
    "month_4" : "april",
    "month_5" : "maj",
    "month_6" : "juni",
    "month_7" : "juli",
    "month_8" : "augusti",
    "month_9" : "september",
    "month_10" : "oktober",
    "month_11" : "november",
    "month_12" : "december",
    "name" : "namn",
    "name_pronounced" : "detta namn",
    "new_booking" : "ny bokning",
    "new_customer" : "ny kund",
    "new_room" : "nytt rum",
    "new_salon" : "ny salong",
    "new_service" : "ny tjänst",
    "new_service_addon" : "ny tilläggstjänst",
    "new_user" : "ny användare",
    "next" : "nästa",
    "no_results" : "inga resultat",
    "none" : "inget",
    "not" : "ej",
    "only" : "enbart",
    "open" : "öppna",
    "order_history" : "orderhistorik",
    "password" : "lösenord",
    "phone" : "telefon",
    "pick" : "välj",
    "postal_code" : "postnummer",
    "previous" : "föregående",
    "price" : "pris",
    "rebook" : "omboka",
    "rebooking" : "ombokning",
    "room" : "rum",
    "room_plural" : "rum",
    "room_pronounced" : "detta rum",
    "salon" : "salong",
    "salon_details" : "salongens uppgifter",
    "salon_plural" : "salonger",
    "saturday" : "lördag",
    "save" : "spara",
    "schedule" : "schema",
    "schedule_mode" : "schemaläge",
    "search" : "sök",
    "selection_state" : "markeringsläge",
    "send_email_notification" : "skicka e-post notifikation",
    "service" : "tjänst",
    "service_addon" : "tilläggstjänst",
    "service_addon_details" : "tillängstjänstens uppgifter",
    "service_addon_plural" : "tilläggstjänster",
    "service_details" : "tjänstens uppgifter",
    "service_plural" : "tjänster",
    "sick" : "sjuk",
    "skin_consultation" : "hudkonsultation",
    "skin_type" : "hudtyp",
    "skin_type_acne" : "akne",
    "skin_type_aging" : "åldrande",
    "skin_type_combination_skin" : "blandhy",
    "skin_type_oily" : "fet hy",
    "skin_type_sensitive" : "känslig hy",
    "skin_type_milia" : "milier",
    "skin_type_normal" : "normal hy",
    "skin_type_pigmentation" : "pigmentfläckar",
    "skin_type_comedones" : "pormaskar",
    "skin_type_rosacea" : "rosacea",
    "skin_type_seborrhea" : "seborré",
    "skin_type_sun_damaged" : "solskadad hy",
    "skin_type_dry" : "torr hy",
    "social_number" : "personnummer",
    "social_number_pronounced" : "detta personnummer",
    "start_time" : "starttid",
    "street" : "gatuadress",
    "sunday" : "söndag",
    "thursday" : "torsdag",
    "time" : "tid",
    "times" : "tider",
    "tuesday" : "tisdag",
    "user" : "användare",
    "user_plural" : "användare",
    "user_details" : "användaruppgifter",
    "warning" : "varning",
    "wednesday" : "onsdag",
    "week" : "vecka",
    "weekday_1_pronounced" : "måndagen den",
    "weekday_2_pronounced" : "tisdagen den",
    "weekday_3_pronounced" : "onsdagen den",
    "weekday_4_pronounced" : "torsdagen den",
    "weekday_5_pronounced" : "fredagen den",
    "weekday_6_pronounced" : "lördagen den",
    "weekday_7_pronounced" : "söndagen den",
    "_could_not_save_model" : "Kunde inte spara %model%.",
    "_customer_with_this_email_already_exists" : "Det finns redan en kund med denna e-post",
    "_customer_with_this_phone_already_exists" : "Det finns redan en kund med detta telefonnummer",
    "_customer_with_this_social_number_already_exists" : "Det finns redan en kund med detta personnummer",
    "_delete_are_you_sure" : "Är du säker på att du vill ta bort %model%? Operationen går inte att ångra.",
    "_enter_alphabet_characters_only" : "enbart bokstäver är tillåtna i detta fält",
    "_enter_alpha_numeric_values_only" : "enbart bokstäver och siffror är tillåtna i detta fält",
    "_enter_numbers_only" : "enbart siffror är tillåtna i detta fält",
    "_enter_valid_phone_without_spaces" : "Ange ett giltigt telefonnummer utan mellanslag (123456789)",
    "_enter_valid_swedish_cellphone_without_spaces" : "Ange ett giltigt mobilnummer utan mellanslag (0712345678)",
    "_enter_valid_swedish_ssn" : "Ange ett giltigt svenskt personnummer utan mellanslag eller bindestreck (YYYYMMDDXXXX)",
    "_enter_valid_cancel_booking_code" : "Ange en giltig bokningskod (ABC123)",
    "_new_booking_body" : '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=utf-8"><meta name="viewport" content="width=device-width"></head><body style="-moz-box-sizing:border-box;-ms-text-size-adjust:100%;-webkit-box-sizing:border-box;-webkit-text-size-adjust:100%;Margin:0;box-sizing:border-box;color:#0a0a0a;font-family:Helvetica,Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;min-width:100%;padding:0;text-align:left;width:100%!important"><style>@media only screen{html{min-height:100%;background:#f3f3f3}}@media only screen and (max-width:596px){.small-float-center{margin:0 auto!important;float:none!important;text-align:center!important}.small-text-center{text-align:center!important}.small-text-left{text-align:left!important}.small-text-right{text-align:right!important}}@media only screen and (max-width:596px){.hide-for-large{display:block!important;width:auto!important;overflow:visible!important;max-height:none!important;font-size:inherit!important;line-height:inherit!important}}@media only screen and (max-width:596px){table.body table.container .hide-for-large,table.body table.container .row.hide-for-large{display:table!important;width:100%!important}}@media only screen and (max-width:596px){table.body table.container .callout-inner.hide-for-large{display:table-cell!important;width:100%!important}}@media only screen and (max-width:596px){table.body table.container .show-for-large{display:none!important;width:0;mso-hide:all;overflow:hidden}}@media only screen and (max-width:596px){table.body img{width:auto;height:auto}table.body center{min-width:0!important}table.body .container{width:95%!important}table.body .column,table.body .columns{height:auto!important;-moz-box-sizing:border-box;-webkit-box-sizing:border-box;box-sizing:border-box;padding-left:16px!important;padding-right:16px!important}table.body .column .column,table.body .column .columns,table.body .columns .column,table.body .columns .columns{padding-left:0!important;padding-right:0!important}table.body .collapse .column,table.body .collapse .columns{padding-left:0!important;padding-right:0!important}td.small-1,th.small-1{display:inline-block!important;width:8.33333%!important}td.small-2,th.small-2{display:inline-block!important;width:16.66667%!important}td.small-3,th.small-3{display:inline-block!important;width:25%!important}td.small-4,th.small-4{display:inline-block!important;width:33.33333%!important}td.small-5,th.small-5{display:inline-block!important;width:41.66667%!important}td.small-6,th.small-6{display:inline-block!important;width:50%!important}td.small-7,th.small-7{display:inline-block!important;width:58.33333%!important}td.small-8,th.small-8{display:inline-block!important;width:66.66667%!important}td.small-9,th.small-9{display:inline-block!important;width:75%!important}td.small-10,th.small-10{display:inline-block!important;width:83.33333%!important}td.small-11,th.small-11{display:inline-block!important;width:91.66667%!important}td.small-12,th.small-12{display:inline-block!important;width:100%!important}.column td.small-12,.column th.small-12,.columns td.small-12,.columns th.small-12{display:block!important;width:100%!important}table.body td.small-offset-1,table.body th.small-offset-1{margin-left:8.33333%!important;Margin-left:8.33333%!important}table.body td.small-offset-2,table.body th.small-offset-2{margin-left:16.66667%!important;Margin-left:16.66667%!important}table.body td.small-offset-3,table.body th.small-offset-3{margin-left:25%!important;Margin-left:25%!important}table.body td.small-offset-4,table.body th.small-offset-4{margin-left:33.33333%!important;Margin-left:33.33333%!important}table.body td.small-offset-5,table.body th.small-offset-5{margin-left:41.66667%!important;Margin-left:41.66667%!important}table.body td.small-offset-6,table.body th.small-offset-6{margin-left:50%!important;Margin-left:50%!important}table.body td.small-offset-7,table.body th.small-offset-7{margin-left:58.33333%!important;Margin-left:58.33333%!important}table.body td.small-offset-8,table.body th.small-offset-8{margin-left:66.66667%!important;Margin-left:66.66667%!important}table.body td.small-offset-9,table.body th.small-offset-9{margin-left:75%!important;Margin-left:75%!important}table.body td.small-offset-10,table.body th.small-offset-10{margin-left:83.33333%!important;Margin-left:83.33333%!important}table.body td.small-offset-11,table.body th.small-offset-11{margin-left:91.66667%!important;Margin-left:91.66667%!important}table.body table.columns td.expander,table.body table.columns th.expander{display:none!important}table.body .right-text-pad,table.body .text-pad-right{padding-left:10px!important}table.body .left-text-pad,table.body .text-pad-left{padding-right:10px!important}table.menu{width:100%!important}table.menu td,table.menu th{width:auto!important;display:inline-block!important}table.menu.small-vertical td,table.menu.small-vertical th,table.menu.vertical td,table.menu.vertical th{display:block!important}table.menu[align=center]{width:auto!important}table.button.small-expand,table.button.small-expanded{width:100%!important}table.button.small-expand table,table.button.small-expanded table{width:100%}table.button.small-expand table a,table.button.small-expanded table a{text-align:center!important;width:100%!important;padding-left:0!important;padding-right:0!important}table.button.small-expand center,table.button.small-expanded center{min-width:0}}</style><table class="body" data-made-with-foundation="" style="Margin:0;background:#f3f3f3;border-collapse:collapse;border-spacing:0;color:#0a0a0a;font-family:Helvetica,Arial,sans-serif;font-size:16px;font-weight:400;height:100%;line-height:1.3;margin:0;padding:0;text-align:left;vertical-align:top;width:100%"><tbody><tr style="padding:0;text-align:left;vertical-align:top"><td class="float-center" align="center" valign="top" style="-moz-hyphens:auto;-webkit-hyphens:auto;Margin:0 auto;border-collapse:collapse!important;color:#0a0a0a;float:none;font-family:Helvetica,Arial,sans-serif;font-size:16px;font-weight:400;hyphens:auto;line-height:1.3;margin:0 auto;padding:0;text-align:center;vertical-align:top;word-wrap:break-word"><center style="min-width:580px;width:100%"><table class="container" style="Margin:0 auto;background:#fefefe;border-collapse:collapse;border-spacing:0;margin:0 auto;padding:0;text-align:inherit;vertical-align:top;width:580px"><tbody><tr style="padding:0;text-align:left;vertical-align:top"><td style="-moz-hyphens:auto;-webkit-hyphens:auto;Margin:0;border-collapse:collapse!important;color:#0a0a0a;font-family:Helvetica,Arial,sans-serif;font-size:16px;font-weight:400;hyphens:auto;line-height:1.3;margin:0;padding:0;text-align:left;vertical-align:top;word-wrap:break-word"><table class="row text-center" style="border-collapse:collapse;border-spacing:0;display:table;padding:0;position:relative;text-align:center;vertical-align:top;width:100%"><tbody><tr style="padding:0;text-align:left;vertical-align:top"><th class="small-12 first columns" style="Margin:0 auto;color:#0a0a0a;font-family:Helvetica,Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0 auto;padding:0;padding-bottom:16px;padding-left:16px;text-align:left"><h1 class="text-center" style="Margin:0;Margin-bottom:10px;color:inherit;font-family:Helvetica,Arial,sans-serif;font-size:34px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center;word-wrap:normal">Bokningsbekräftelse</h1><h4 class="text-center" style="Margin:0;Margin-bottom:10px;color:inherit;font-family:Helvetica,Arial,sans-serif;font-size:24px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center;word-wrap:normal">Hej %customer_name%!</h4><p class="text-center" style="Margin:0;Margin-bottom:10px;color:#0a0a0a;font-family:Helvetica,Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center">Vi har tagit emot din bokning enligt nedan</p><h6 class="text-center" style="Margin:0;Margin-bottom:10px;color:inherit;font-family:Helvetica,Arial,sans-serif;font-size:18px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center;word-wrap:normal">%service_name%</h6><p class="text-center" style="Margin:0;Margin-bottom:10px;color:#0a0a0a;font-family:Helvetica,Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center">%salon_name%<br>%salon_address%</p><p class="text-center" style="Margin:0;Margin-bottom:10px;color:#0a0a0a;font-family:Helvetica,Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center">%date%</p><p class="text-center" style="Margin:0;Margin-bottom:10px;color:#0a0a0a;font-family:Helvetica,Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center">kl %start_time%-%end_time%</p><p class="text-center" style="Margin:0;Margin-bottom:10px;color:#0a0a0a;font-family:Helvetica,Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center">Utövare: %user_name%</p><h5 class="text-center" style="Margin:0;Margin-bottom:10px;color:inherit;font-family:Helvetica,Arial,sans-serif;font-size:20px;font-weight:400;line-height:1.3;margin:0;margin-bottom:10px;padding:0;text-align:center;word-wrap:normal">Välkommen!</h5></th><th class="expander" style="Margin:0;color:#0a0a0a;font-family:Helvetica,Arial,sans-serif;font-size:16px;font-weight:400;line-height:1.3;margin:0;padding:0!important;text-align:left;visibility:hidden;width:0"></th></tr></tbody></table></td></tr></tbody></table></center></td></tr></tbody></table></body></html>',
    "_salon_is_closed_this_week" : "det finns inga öppna tider för salongen denna vecka",
    "_salon_with_this_name_already_exists" : "Det finns redan en salong med detta namn",
    "_service_with_this_name_already_exists" : "Det finns redan en tjänst med detta namn",
    "_service_addon_with_this_name_already_exists" : "Det finns redan en tilläggstjänst med detta namn",
    "_ui_name_service_addon" : "%name% [%duration% min, %price% kr]",
    "_user_with_this_email_already_exists" : "Det finns redan en användare med denna e-post",
    "_user_with_this_phone_already_exists" : "Det finns redan en användare med detta telefonnummer",
    "_user_with_this_social_number_already_exists" : "Det finns redan en användare med detta personnummer",
    "_Error: The email address is already in use by another account." : "Det finns redan en användare med denna e-post.",
    "_Error: Password should be at least 6 characters" : "Lösenordet måste innehålla minst 6 tecken",
  };
}

==> bokain_models-0.2.77.tar.gz: lib/src/phrase.dart <==
class Phrase
{
  String get(List<String> phrase_keys, { Map<String, String> params : null, String separator : " ", bool capitalize_first : true})
  {
    List<String> phraseValues = new List();
    for (String key in phrase_keys)
    {
      if (key == null) return "";
      String value = key = key.toLowerCase();

      if (_phraseData.containsKey(key))
      {
        value = _phraseData[key];
        params?.forEach((paramName, paramVal)
        {
          value = value.replaceAll("%$paramName%", paramVal);
        });
      }
      phraseValues.add(value);
    }
    String phrase = phraseValues.join(separator);
    if (capitalize_first == true) phrase = phrase[0].toUpperCase() + phrase.substring(1, phrase.length);

    return phrase;
  }

  final Map<String, String> _phraseData =
  {
    "1_pronounced" : "1:a",
    "2_prounounced" : "2:a",
    "3_pronounced" : "3:e",
    "4_pronounced" : "4:e",
    "5_pronounced" : "5:e",
    "6_pronounced" : "6:e",
    "7_pronounced" : "7:e",
    "8_pronounced" : "8:e",
    "9_pronounced" : "9:e",
    "10_pronounced" : "10:e",
    "11_pronounced" : "11:e",
    "12_pronounced" : "12:e",
    "13_pronounced" : "13:e",
    "14_pronounced" : "14:e",
    "15_pronounced" : "15:e",
    "16_pronounced" : "16:e",
    "17_pronounced" : "17:e",
    "18_pronounced" : "18:e",
    "19_pronounced" : "19:e",
    "20_pronounced" : "20:e",
    "21_pronounced" : "21:a",
    "22_pronounced" : "22:a",
    "23_pronounced" : "23:e",
    "24_pronounced" : "24:e",
    "25_pronounced" : "25:e",
    "26_pronounced" : "26:e",
    "27_pronounced" : "27:e",
    "28_pronounced" : "28:e",
    "29_pronounced" : "29:e",
    "30_pronounced" : "30:e",
    "31_pronounced" : "31:a",
    "32_pronounced" : "32:a",
    "active" : "aktiv",
    "add" : "lägg till",
    "associate" : "anslut",
    "associated" : "ansluten",
    "associated_plural" : "anslutna",
    "at" : "på",
    "belongs_to" : "tillhör",
    "book" : "boka in",
    "bookable_plural" : "bokningsbara",
    "booking" : "bokning",
    "booking_cancel" : "avboka",
    "booking_confirm" : "bekräfta bokning",
    "booking_confirm_text" :  "kontrollera att uppgifterna ovan stämmer innan du slutför bokningen",
    "booking_confirmation" : "bokningsbekräftelse",
    "booking_confirmation_send" : "skicka bokningsbekräftelse till kunden",
    "booking_details" : "bokningsinformation",
    "booking_history" : "bokningshistorik",
    "booking_mode" : "bokningsläge",
    "booking_plural" : "bokningar",
    "booking_rank" : "bokningsranking",
    "break" : "rast",
    "calendar" : "kalender",
    "cancel" : "avbryt",
    "category" : "kategori",
    "city" : "stad",
    "close" : "stäng",
    "confirm" : "bekräfta",
    "confirm_remove" : "bekräfta borttagning av objekt",
    "confirm_save" : "du har osparade ändringar, tryck OK för att spara eller AVBRYT för att ignorera ändringarna",
    "comments_external" : "kommentarer (externa)",
    "comments_internal" : "kommentarer (interna)",
    "country" : "land",
    "country_gb" : "storbritannien",
    "country_se" : "sverige",
    "currency" : "kr",
    "customer" : "kund",
    "customer_plural" : "kunder",
    "customer_details" : "kunduppgifter",
    "dashboard" : "dashboard",
    "delete" : "ta bort",
    "description" : "beskrivning",
    "details" : "uppgifter",
    "disabled" : "inaktiverad",
    "duration" : "varaktighet",
    "duration_minutes" : "varaktighet (minuter)",
    "dynamic_time" : "dynamisk tid",
    "edit" : "redigera",
    "email" : "e-post",
    "email_pronounced" : "denna e-post",
    "error_occured" : "ett fel inträffade",
    "finish" : "slutför",
    "friday" : "fredag",
    "in_minutes" : "(minuter)",
    "information" : "information",
    "firstname" : "förnamn",
    "frozen" : "fryst",
    "function" : "funktion",
    "language" : "språk",
    "language_en" : "engelska",
    "language_sv" : "svenska",
    "lastname" : "efternamn",
    "login" : "logga in",
    "monday" : "måndag",
    "month" : "månad",
    "month_1" : "januari",
    "month_2" : "februari",
    "month_3" : "mars",
    "month_4" : "april",
    "month_5" : "maj",
    "month_6" : "juni",
    "month_7" : "juli",
    "month_8" : "augusti",
    "month_9" : "september",
    "month_10" : "oktober",
    "month_11" : "november",
    "month_12" : "december",
    "name" : "namn",
    "name_pronounced" : "detta namn",
    "new_booking" : "ny bokning",
    "new_customer" : "ny kund",
    "new_room" : "nytt rum",
    "new_salon" : "ny salong",
    "new_service" : "ny tjänst",
    "new_service_addon" : "ny tilläggstjänst",
    "new_user" : "ny användare",
    "next" : "nästa",
    "no_results" : "inga resultat",
    "none" : "inget",
    "not" : "ej",
    "only" : "enbart",
    "open" : "öppna",
    "order_history" : "orderhistorik",
    "password" : "lösenord",
    "phone" : "telefon",
    "pick" : "välj",
    "postal_code" : "postnummer",
    "previous" : "föregående",
    "price" : "pris",
    "rebook" : "omboka",
    "rebooking" : "ombokning",
    "room" : "rum",
    "room_plural" : "rum",
    "room_pronounced" : "detta rum",
    "salon" : "salong",
    "salon_details" : "salongens uppgifter",
    "salon_plural" : "salonger",
    "saturday" : "lördag",
    "save" : "spara",
    "schedule" : "schema",
    "schedule_mode" : "schemaläge",
    "search" : "sök",
    "selection_state" : "markeringsläge",
    "send_email_notification" : "skicka e-post notifikation",
    "service" : "tjänst",
    "service_addon" : "tilläggstjänst",
    "service_addon_details" : "tillängstjänstens uppgifter",
    "service_addon_plural" : "tilläggstjänster",
    "service_details" : "tjänstens uppgifter",
    "service_plural" : "tjänster",
    "sick" : "sjuk",
    "skin_consultation" : "hudkonsultation",
    "skin_type" : "hudtyp",
    "skin_type_acne" : "akne",
    "skin_type_aging" : "åldrande",
    "skin_type_combination_skin" : "blandhy",
    "skin_type_oily" : "fet hy",
    "skin_type_sensitive" : "känslig hy",
    "skin_type_milia" : "milier",
    "skin_type_normal" : "normal hy",
    "skin_type_pigmentation" : "pigmentfläckar",
    "skin_type_comedones" : "pormaskar",
    "skin_type_rosacea" : "rosacea",
    "skin_type_seborrhea" : "seborré",
    "skin_type_sun_damaged" : "solskadad hy",
    "skin_type_dry" : "torr hy",
    "social_number" : "personnummer",
    "social_number_pronounced" : "detta personnummer",
    "start_time" : "starttid",
    "street" : "gatuadress",
    "sunday" : "söndag",
    "thursday" : "torsdag",
    "time" : "tid",
    "times" : "tider",
    "tuesday" : "tisdag",
    "user" : "användare",
    "user_plural" : "användare",
    "user_details" : "användaruppgifter",
    "warning" : "varning",
    "wednesday" : "onsdag",
    "week" : "vecka",
    "weekday_1_pronounced" : "måndagen den",
    "weekday_2_pronounced" : "tisdagen den",
    "weekday_3_pronounced" : "onsdagen den",
    "weekday_4_pronounced" : "torsdagen den",
    "weekday_5_pronounced" : "fredagen den",
    "weekday_6_pronounced" : "lördagen den",
    "weekday_7_pronounced" : "söndagen den",
    "_could_not_save_model" : "Kunde inte spara %model%.",
    "_customer_with_this_email_already_exists" : "Det finns redan en kund med denna e-post",
    "_customer_with_this_phone_already_exists" : "Det finns redan en kund med detta telefonnummer",
    "_customer_with_this_social_number_already_exists" : "Det finns redan en kund med detta personnummer",
    "_delete_are_you_sure" : "Är du säker på att du vill ta bort %model%? Operationen går inte att ångra.",
    "_enter_alphabet_characters_only" : "enbart bokstäver är tillåtna i detta fält",
    "_enter_alpha_numeric_values_only" : "enbart bokstäver och siffror är tillåtna i detta fält",
    "_enter_numbers_only" : "enbart siffror är tillåtna i detta fält",
    "_enter_valid_phone_without_spaces" : "Ange ett giltigt telefonnummer utan mellanslag (123456789)",
    "_enter_valid_swedish_cellphone_without_spaces" : "Ange ett giltigt mobilnummer utan mellanslag (0712345678)",
    "_enter_valid_swedish_ssn" : "Ange ett giltigt svenskt personnummer utan mellanslag eller bindestreck (YYYYMMDDXXXX)",
    "_enter_valid_cancel_booking_code" : "Ange en giltig bokningskod (ABC123)",
    "_new_booking_body" : '<table class="row text-center"><tr><th class="small-12 first columns"><h1 class="text-center">Bokningsbekräftelse</h1><h4 class="text-center">Hej %customer_name%!</h4><p class="text-center">Vi har tagit emot din bokning enligt nedan</p><h6 class="text-center">%service_name%</h6><p class="text-center">%salon_name%<br/>%salon_address%</p><p class="text-center">%date%</p><p class="text-center">kl %start_time%-%end_time%</p><p class="text-center">Utövare: %user_name%</p><h5 class="text-center">Välkommen!</h5></th><th class="expander"></th></tr></table>',
    "_salon_is_closed_this_week" : "det finns inga öppna tider för salongen denna vecka",
    "_salon_with_this_name_already_exists" : "Det finns redan en salong med detta namn",
    "_service_with_this_name_already_exists" : "Det finns redan en tjänst med detta namn",
    "_service_addon_with_this_name_already_exists" : "Det finns redan en tilläggstjänst med detta namn",
    "_ui_name_service_addon" : "%name% [%duration% min, %price% kr]",
    "_user_with_this_email_already_exists" : "Det finns redan en användare med denna e-post",
    "_user_with_this_phone_already_exists" : "Det finns redan en användare med detta telefonnummer",
    "_user_with_this_social_number_already_exists" : "Det finns redan en användare med detta personnummer",
    "_Error: The email address is already in use by another account." : "Det finns redan en användare med denna e-post.",
    "_Error: Password should be at least 6 characters" : "Lösenordet måste innehålla minst 6 tecken",
  };
}
